@@ -1,10 +1,11 @@
 import enum
 import itertools
-from typing import List, Tuple, Iterable
+from typing import List, Tuple, Iterable, Sequence
 
 from asttokens import ASTTokens  # type: ignore[import]
 
 from .ast import Position
+from .exceptions import TuckError
 
 INDENT_SIZE = 4
 
@@ -18,12 +19,17 @@ class MutationType(enum.Enum):
     CLOSE_PAREN = 'close_paren'
 
 
-WrappingSummary = List[Tuple['Position', MutationType]]
-Insertion = Tuple['Position', str]
+WrappingSummary = List[Tuple[Position, MutationType]]
+Insertion = Tuple[Position, str]
 
 
-class EditsOverlapError(Exception):
-    pass
+class EditsOverlapError(TuckError):
+    def __init__(self) -> None:
+        super().__init__(
+            'edits_overlap',
+            "Unable to perform wrapping as the resulting edits contain overlaps. "
+            "Consider wrapping the positions one at a time instead. ",
+        )
 
 
 def indent_interim_lines(
@@ -100,7 +106,7 @@ def merge_insertions(grouped_insertions: Iterable[List[Insertion]]) -> List[Inse
     return flat_insertions
 
 
-def apply_insertions(content: str, insertions: List[Insertion]) -> str:
+def apply_insertions(content: str, insertions: Sequence[Insertion]) -> str:
     new_content = content.splitlines(keepends=True)
 
     for position, insertion in reversed(insertions):
